# SEC11-BP02: Automate testing throughout the development and release lifecycle

## Description

SAST/DAST.

## Implementation Guidance

- SAST in CI/CD
- DAST for running applications
- Dependency scanning
- Container image scanning
- IaC security scanning

## Risk Level

High - Manual testing misses vulnerabilities.
